@@ -1,4 +1,19 @@
 
+#' Create graphs from adjacency matrices
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.adjacency()` was renamed to `graph_from_adjacency_matrix()` to create a more
+#' consistent API.
+#' @inheritParams graph_from_adjacency_matrix
+#' @keywords internal
+#' @export
+graph.adjacency <- function(adjmatrix, mode = c("directed", "undirected", "max", "min", "upper", "lower", "plus"), weighted = NULL, diag = TRUE, add.colnames = NULL, add.rownames = NA) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.adjacency()", "graph_from_adjacency_matrix()")
+  graph_from_adjacency_matrix(adjmatrix = adjmatrix, mode = mode, weighted = weighted, diag = diag, add.colnames = add.colnames, add.rownames = add.rownames)
+} # nocov end
+
 ## ----------------------------------------------------------------
 ##
 ##   IGraph R package
@@ -22,54 +37,49 @@
 ##
 ## -----------------------------------------------------------------
 
-graph.adjacency.dense <- function(adjmatrix,
-                                  mode = c(
-                                    "directed", "undirected", "max",
-                                    "min", "upper", "lower", "plus"
-                                  ),
-                                  weighted = NULL, diag = TRUE) {
-  mode <- igraph.match.arg(mode)
+graph.adjacency.dense <- function(
+    adjmatrix,
+    mode,
+    weighted = NULL,
+    diag = c("once", "twice", "ignore")) {
   mode <- switch(mode,
-    "directed" = 0,
-    "undirected" = 1,
-    "max" = 1,
-    "upper" = 2,
-    "lower" = 3,
-    "min" = 4,
-    "plus" = 5
+    "directed" = 0L,
+    "undirected" = 1L,
+    "upper" = 2L,
+    "lower" = 3L,
+    "min" = 4L,
+    "plus" = 5L,
+    "max" = 6L
   )
 
+  if (is.logical(diag)) {
+    diag <- ifelse(diag, "once", "ignore")
+  }
+  diag <- igraph.match.arg(diag)
+  diag <- switch(diag,
+    "ignore" = 0L,
+    "twice" = 1L,
+    "once" = 2L
+  )
+
+  if (nrow(adjmatrix) != ncol(adjmatrix)) {
+    stop("Adjacency matrices must be square.")
+  }
+
   mode(adjmatrix) <- "double"
 
-  if (!is.null(weighted)) {
-    if (is.logical(weighted) && weighted) {
-      weighted <- "weight"
-    }
-    if (!is.character(weighted)) {
-      stop("invalid value supplied for `weighted' argument, please see docs.")
-    }
+  if (isTRUE(weighted)) {
+    weighted <- "weight"
+  } else if (!is.character(weighted)) {
+    weighted <- NULL
+  }
 
-    if (nrow(adjmatrix) != ncol(adjmatrix)) {
-      stop("not a square matrix")
-    }
-
-    on.exit(.Call(R_igraph_finalizer))
-    res <- .Call(
-      R_igraph_weighted_adjacency, adjmatrix,
-      as.numeric(mode), weighted, diag
-    )
+  on.exit(.Call(R_igraph_finalizer))
+  if (is.null(weighted)) {
+    res <- .Call(R_igraph_adjacency, adjmatrix, mode, diag)
   } else {
-    adjmatrix <- as.matrix(adjmatrix)
-    attrs <- attributes(adjmatrix)
-    adjmatrix <- as.numeric(adjmatrix)
-    attributes(adjmatrix) <- attrs
-
-    if (!diag) {
-      diag(adjmatrix) <- 0
-    }
-
-    on.exit(.Call(R_igraph_finalizer))
-    res <- .Call(R_igraph_graph_adjacency, adjmatrix, as.numeric(mode))
+    res <- .Call(R_igraph_weighted_adjacency, adjmatrix, mode, diag)
+    res <- set_edge_attr(res$graph, weighted, value = res$weights)
   }
 
   res
@@ -87,13 +97,7 @@ mysummary <- function(x) {
 }
 
 
-graph.adjacency.sparse <- function(adjmatrix, mode = c(
-                                     "directed", "undirected", "max",
-                                     "min", "upper", "lower", "plus"
-                                   ),
-                                   weighted = NULL, diag = TRUE) {
-  mode <- igraph.match.arg(mode)
-
+graph.adjacency.sparse <- function(adjmatrix, mode, weighted = NULL, diag = TRUE) {
   if (!is.null(weighted)) {
     if (is.logical(weighted) && weighted) {
       weighted <- "weight"
@@ -116,10 +120,6 @@ graph.adjacency.sparse <- function(adjmatrix, mode = c(
     adjmatrix <- as(adjmatrix, "CsparseMatrix")
   }
 
-  if (is.null(weighted) && mode == "undirected") {
-    mode <- "max"
-  }
-
   if (mode == "directed") {
     ## DIRECTED
     el <- mysummary(adjmatrix)
@@ -134,9 +134,15 @@ graph.adjacency.sparse <- function(adjmatrix, mode = c(
     if (diag) {
       adjmatrix <- Matrix::tril(adjmatrix)
     } else {
-      adjmatrix <- Matrix::tril(adjmatrix, -1)
+      if (vc == 1) {
+        # Work around Matrix glitch
+        adjmatrix <- as(matrix(0), "dgCMatrix")
+      } else {
+        adjmatrix <- Matrix::tril(adjmatrix, -1)
+      }
     }
     el <- mysummary(adjmatrix)
+    rm(adjmatrix)
   } else if (mode == "max") {
     ## MAXIMUM
     el <- mysummary(adjmatrix)
@@ -181,7 +187,12 @@ graph.adjacency.sparse <- function(adjmatrix, mode = c(
     if (diag) {
       adjmatrix <- Matrix::tril(adjmatrix)
     } else {
-      adjmatrix <- Matrix::tril(adjmatrix, -1)
+      if (vc == 1) {
+        # Work around Matrix glitch
+        adjmatrix <- as(matrix(0), "dgCMatrix")
+      } else {
+        adjmatrix <- Matrix::tril(adjmatrix, -1)
+      }
     }
     el <- mysummary(adjmatrix)
     rm(adjmatrix)
@@ -192,6 +203,7 @@ graph.adjacency.sparse <- function(adjmatrix, mode = c(
     ## MINIMUM
     adjmatrix <- sign(adjmatrix) * sign(Matrix::t(adjmatrix)) * adjmatrix
     el <- mysummary(adjmatrix)
+    rm(adjmatrix)
     if (!diag) {
       el <- el[el[, 1] != el[, 2], ]
     }
@@ -221,15 +233,20 @@ graph.adjacency.sparse <- function(adjmatrix, mode = c(
     if (diag) {
       adjmatrix <- Matrix::tril(adjmatrix)
     } else {
-      adjmatrix <- Matrix::tril(adjmatrix, -1)
+      if (vc == 1) {
+        # Work around Matrix glitch
+        adjmatrix <- as(matrix(0), "dgCMatrix")
+      } else {
+        adjmatrix <- Matrix::tril(adjmatrix, -1)
+      }
     }
     el <- mysummary(adjmatrix)
+    rm(adjmatrix)
     if (diag) {
       loop <- el[, 1] == el[, 2]
       el[loop, 3] <- el[loop, 3] / 2
     }
     el <- el[el[, 3] != 0, ]
-    rm(adjmatrix)
   }
 
   if (!is.null(weighted)) {
@@ -292,7 +309,6 @@ graph.adjacency.sparse <- function(adjmatrix, mode = c(
 #' undirected graph will be created, `A(i,j)+A(j,i)` gives the edge
 #' weights.} }
 #'
-#' @aliases graph.adjacency
 #' @param adjmatrix A square adjacency matrix. From igraph version 0.5.1 this
 #'   can be a sparse matrix created with the `Matrix` package.
 #' @param mode Character scalar, specifies how igraph should interpret the
@@ -385,6 +401,28 @@ graph_from_adjacency_matrix <- function(adjmatrix,
                                         ),
                                         weighted = NULL, diag = TRUE,
                                         add.colnames = NULL, add.rownames = NA) {
+
+  mode <- igraph.match.arg(mode)
+
+  if (!is.matrix(adjmatrix) && !inherits(adjmatrix, "Matrix")) {
+    lifecycle::deprecate_soft(
+      "1.6.0",
+      "graph_from_adjacency_matrix(adjmatrix = 'must be a matrix')"
+    )
+    adjmatrix <- as.matrix(1)
+  }
+
+  if (mode == "undirected") {
+    if (!is_symmetric(adjmatrix)) {
+      lifecycle::deprecate_soft(
+        "1.6.0",
+        "graph_from_adjacency_matrix(adjmatrix = 'must be symmetric with mode = \"undirected\"')",
+        details = 'Use mode = "max" to achieve the original behavior.'
+      )
+      mode <- "max"
+    }
+  }
+
   if (inherits(adjmatrix, "Matrix")) {
     res <- graph.adjacency.sparse(adjmatrix, mode = mode, weighted = weighted, diag = diag)
   } else {
@@ -434,6 +472,16 @@ graph_from_adjacency_matrix <- function(adjmatrix,
   res
 }
 
+is_symmetric <- function(x) {
+  if (inherits(x, "Matrix")) {
+    Matrix::isSymmetric(x, tol = 0, tol1 = 0)
+  } else if (is.matrix(x)) {
+    isSymmetric.matrix(x, tol = 0, tol1 = 0)
+  } else {
+    isSymmetric(x, tol = 0, tol1 = 0)
+  }
+}
+
 #' @rdname graph_from_adjacency_matrix
 #' @param ... Passed to `graph_from_adjacency_matrix()`.
 #' @family adjacency
