@@ -1,3 +1,168 @@
+
+#' Find subgraph centrality scores of network positions
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `subgraph.centrality()` was renamed to `subgraph_centrality()` to create a more
+#' consistent API.
+#' @inheritParams subgraph_centrality
+#' @keywords internal
+#' @export
+subgraph.centrality <- function(graph, diag = FALSE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "subgraph.centrality()", "subgraph_centrality()")
+  subgraph_centrality(graph = graph, diag = diag)
+} # nocov end
+
+#' The Page Rank algorithm
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `page.rank()` was renamed to `page_rank()` to create a more
+#' consistent API.
+#' @inheritParams page_rank
+#' @keywords internal
+#' @export
+page.rank <- function(graph, algo = c("prpack", "arpack"), vids = V(graph), directed = TRUE, damping = 0.85, personalized = NULL, weights = NULL, options = NULL) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "page.rank()", "page_rank()")
+  page_rank(graph = graph, algo = algo, vids = vids, directed = directed, damping = damping, personalized = personalized, weights = weights, options = options)
+} # nocov end
+
+#' Kleinberg's hub and authority centrality scores.
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `hub.score()` was renamed to `hub_score()` to create a more
+#' consistent API.
+#' @inheritParams hub_score
+#' @keywords internal
+#' @export
+hub.score <- function(graph, scale = TRUE, weights = NULL, options = arpack_defaults()) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "hub.score()", "hub_score()")
+  hub_score(graph = graph, scale = scale, weights = weights, options = options)
+} # nocov end
+
+#' Strength or weighted vertex degree
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.strength()` was renamed to `strength()` to create a more
+#' consistent API.
+#' @inheritParams strength
+#' @keywords internal
+#' @export
+graph.strength <- function(graph, vids = V(graph), mode = c("all", "out", "in", "total"), loops = TRUE, weights = NULL) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.strength()", "strength()")
+  strength(graph = graph, vids = vids, mode = mode, loops = loops, weights = weights)
+} # nocov end
+
+#' Eigenvalues and eigenvectors of the adjacency matrix of a graph
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.eigen()` was renamed to `spectrum()` to create a more
+#' consistent API.
+#' @inheritParams spectrum
+#' @keywords internal
+#' @export
+graph.eigen <- function(graph, algorithm = c("arpack", "auto", "lapack", "comp_auto", "comp_lapack", "comp_arpack"), which = list(), options = arpack_defaults()) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.eigen()", "spectrum()")
+  spectrum(graph = graph, algorithm = algorithm, which = which, options = options)
+} # nocov end
+
+#' Graph diversity
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `graph.diversity()` was renamed to `diversity()` to create a more
+#' consistent API.
+#' @inheritParams diversity
+#' @keywords internal
+#' @export
+graph.diversity <- function(graph, weights = NULL, vids = V(graph)) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "graph.diversity()", "diversity()")
+  diversity(graph = graph, weights = weights, vids = vids)
+} # nocov end
+
+#' Find Eigenvector Centrality Scores of Network Positions
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `evcent()` was renamed to `eigen_centrality()` to create a more
+#' consistent API.
+#' @inheritParams eigen_centrality
+#' @keywords internal
+#' @export
+evcent <- function(graph, directed = FALSE, scale = TRUE, weights = NULL, options = arpack_defaults()) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "evcent()", "eigen_centrality()")
+  eigen_centrality(graph = graph, directed = directed, scale = scale, weights = weights, options = options)
+} # nocov end
+
+#' Vertex and edge betweenness centrality
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `edge.betweenness()` was renamed to `edge_betweenness()` to create a more
+#' consistent API.
+#' @inheritParams edge_betweenness
+#' @keywords internal
+#' @export
+edge.betweenness <- function(graph, e = E(graph), directed = TRUE, weights = NULL, cutoff = -1) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "edge.betweenness()", "edge_betweenness()")
+  edge_betweenness(graph = graph, e = e, directed = directed, weights = weights, cutoff = cutoff)
+} # nocov end
+
+#' Find Bonacich Power Centrality Scores of Network Positions
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `bonpow()` was renamed to `power_centrality()` to create a more
+#' consistent API.
+#' @inheritParams power_centrality
+#' @keywords internal
+#' @export
+bonpow <- function(graph, nodes = V(graph), loops = FALSE, exponent = 1, rescale = FALSE, tol = 1e-7, sparse = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "bonpow()", "power_centrality()")
+  power_centrality(graph = graph, nodes = nodes, loops = loops, exponent = exponent, rescale = rescale, tol = tol, sparse = sparse)
+} # nocov end
+
+#' Kleinberg's hub and authority centrality scores.
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `authority.score()` was renamed to `authority_score()` to create a more
+#' consistent API.
+#' @inheritParams authority_score
+#' @keywords internal
+#' @export
+authority.score <- function(graph, scale = TRUE, weights = NULL, options = arpack_defaults()) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "authority.score()", "authority_score()")
+  authority_score(graph = graph, scale = scale, weights = weights, options = options)
+} # nocov end
+
+#' Find Bonacich alpha centrality scores of network positions
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `alpha.centrality()` was renamed to `alpha_centrality()` to create a more
+#' consistent API.
+#' @inheritParams alpha_centrality
+#' @keywords internal
+#' @export
+alpha.centrality <- function(graph, nodes = V(graph), alpha = 1, loops = FALSE, exo = 1, weights = NULL, tol = 1e-7, sparse = TRUE) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "alpha.centrality()", "alpha_centrality()")
+  alpha_centrality(graph = graph, nodes = nodes, alpha = alpha, loops = loops, exo = exo, weights = weights, tol = tol, sparse = sparse)
+} # nocov end
 #   IGraph R package
 #   Copyright (C) 2005-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -21,15 +186,16 @@
 
 #' Deprecated version of `betweenness()`
 #'
-#' @description Use [`betweenness()`] with the `cutoff` argument instead.
+#' @description
 #' `r lifecycle::badge("deprecated")`
+#'
+#' Use [`betweenness()`] with the `cutoff` argument instead.
 #' @param vids The vertices for which the vertex betweenness estimation will be
 #'   calculated.
 #' @inheritParams betweenness
 #' @keywords internal
 #' @export
 estimate_betweenness <- function(graph, vids = V(graph), directed = TRUE, cutoff, weights = NULL) {
-
   lifecycle::deprecate_soft(
     "1.6.0",
     "estimate_betweenness()",
@@ -67,17 +233,16 @@ betweenness.estimate <- estimate_betweenness
 #'
 #' Both functions allow you to consider only paths of length `cutoff` or
 #' smaller; this can be run for larger graphs, as the running time is not
-#' quadratic (if `cutoff` is small). If `cutoff` is zero or negative,
-#' then the function calculates the exact betweenness scores. Using zero as a
-#' cutoff is *deprecated* and future versions (from 1.4.0) will treat zero
-#' cutoff literally (i.e. no paths considered at all). If you want no cutoff,
-#' use a negative number.
+#' quadratic (if `cutoff` is small). If `cutoff` is negative (the default),
+#' then the function calculates the exact betweenness scores. Since igraph 1.6.0,
+#' a `cutoff` value of zero is treated literally, i.e. paths of length larger
+#' than zero are ignored.
 #'
 #' For calculating the betweenness a similar algorithm to the one proposed by
 #' Brandes (see References) is used.
 #'
-#' @aliases betweenness edge.betweenness betweenness.estimate
-#' edge.betweenness.estimate edge_betweenness
+#' @aliases betweenness.estimate
+#' @aliases edge.betweenness.estimate
 #' @param graph The graph to analyze.
 #' @param v The vertices for which the vertex betweenness will be calculated.
 #' @param directed Logical, whether directed paths should be considered while
@@ -86,8 +251,6 @@ betweenness.estimate <- estimate_betweenness
 #'   betweenness. If the graph has a `weight` edge attribute, then this is
 #'   used by default. Weights are used to calculate weighted shortest paths,
 #'   so they are interpreted as distances.
-#' @param nobigint Logical scalar, whether to use big integers during the
-#'   calculation. Deprecated since igraph 1.3 and will be removed in igraph 1.4.
 #' @param normalized Logical scalar, whether to normalize the betweenness
 #'   scores. If `TRUE`, then the results are normalized by the number of ordered
 #'   or unordered vertex pairs in directed and undirected graphs, respectively.
@@ -122,7 +285,7 @@ betweenness.estimate <- estimate_betweenness
 #' @param cutoff The maximum path length to consider when calculating the
 #'   betweenness. If zero or negative then there is no such limit.
 betweenness <- function(graph, v = V(graph), directed = TRUE, weights = NULL,
-                        nobigint = TRUE, normalized = FALSE, cutoff = -1) {
+                        normalized = FALSE, cutoff = -1) {
   ensure_igraph(graph)
 
   v <- as_igraph_vs(graph, v)
@@ -136,13 +299,6 @@ betweenness <- function(graph, v = V(graph), directed = TRUE, weights = NULL,
     weights <- NULL
   }
   cutoff <- as.numeric(cutoff)
-  if (cutoff == 0) {
-    warning("`cutoff' == 0 will be treated literally from igraph 1.4. If you want unrestricted betweenness, set it to -1")
-    cutoff <- -1
-  }
-  if (!missing(nobigint)) {
-    warning("'nobigint' is deprecated since igraph 1.3 and will be removed in igraph 1.4")
-  }
   on.exit(.Call(R_igraph_finalizer))
   res <- .Call(R_igraph_betweenness_cutoff, graph, v - 1, directed, weights, cutoff)
   if (normalized) {
@@ -161,7 +317,6 @@ betweenness <- function(graph, v = V(graph), directed = TRUE, weights = NULL,
 
 #' @rdname betweenness
 #' @param e The edges for which the edge betweenness will be calculated.
-#' @family centrality
 #' @export
 edge_betweenness <- function(graph, e = E(graph),
                              directed = TRUE, weights = NULL, cutoff = -1) {
@@ -179,10 +334,6 @@ edge_betweenness <- function(graph, e = E(graph),
     weights <- NULL
   }
   cutoff <- as.numeric(cutoff)
-  if (cutoff == 0) {
-    warning("`cutoff' == 0 will be treated literally from igraph 1.4. If you want unrestricted edge betweenness, set it to -1")
-    cutoff <- -1
-  }
 
   on.exit(.Call(R_igraph_finalizer))
   # Function call
@@ -193,9 +344,9 @@ edge_betweenness <- function(graph, e = E(graph),
 #' Deprecated version of `edge_betweenness()`
 #'
 #' @description
-#' Use [`edge_betweenness()`] with the `cutoff` argument instead.
 #' `r lifecycle::badge("deprecated")`
 #'
+#' Use [`edge_betweenness()`] with the `cutoff` argument instead.
 #' @inheritParams edge_betweenness
 #' @keywords internal
 #' @export
@@ -229,17 +380,16 @@ edge.betweenness.estimate <- estimate_edge_betweenness
 #'
 # " You may use the \code{cutoff} argument to consider only paths of length
 #' `cutoff` or smaller. This can be run for larger graphs, as the running
-#' time is not quadratic (if `cutoff` is small). If `cutoff` is zero
-#' or negative (which is the default), then the function calculates the exact
-#' closeness scores. Using zero as a cutoff is *deprecated* and future
-#' versions (from 1.4.0) will treat zero cutoff literally (i.e. no paths
-#' considered at all). If you want no cutoff, use a negative number.
+#' time is not quadratic (if `cutoff` is small). If `cutoff` is
+#' negative (which is the default), then the function calculates the exact
+#' closeness scores. Since igraph 1.6.0, a `cutoff` value of zero is treated
+#' literally, i.e. path with a length greater than zero are ignored.
 #'
 #' Closeness centrality is meaningful only for connected graphs. In disconnected
 #' graphs, consider using the harmonic centrality with
 #' [harmonic_centrality()]
 #'
-#' @aliases closeness closeness.estimate
+#' @aliases closeness.estimate
 #' @param graph The graph to analyze.
 #' @param vids The vertices for which closeness will be calculated.
 #' @param mode Character string, defined the types of the paths used for
@@ -260,7 +410,6 @@ edge.betweenness.estimate <- estimate_edge_betweenness
 #' @return Numeric vector with the closeness values of all the vertices in
 #'   `v`.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
-#' @seealso [betweenness()], [degree()], [harmonic_centrality()]
 #' @references Freeman, L.C. (1979). Centrality in Social Networks I:
 #' Conceptual Clarification. *Social Networks*, 1, 215-239.
 #' @family centrality
@@ -298,10 +447,6 @@ closeness <- function(graph, vids = V(graph),
   }
   normalized <- as.logical(normalized)
   cutoff <- as.numeric(cutoff)
-  if (cutoff == 0) {
-    warning("`cutoff' == 0 will be treated literally from igraph 1.4. If you want unrestricted closeness, set it to -1")
-    cutoff <- -1
-  }
 
   on.exit(.Call(R_igraph_finalizer))
   # Function call
@@ -315,9 +460,9 @@ closeness <- function(graph, vids = V(graph),
 #' Deprecated version of `closeness()`
 #'
 #' @description
-#' Use [`closeness()`] with the `cutoff` argument instead.
 #' `r lifecycle::badge("deprecated")`
 #'
+#' Use [`closeness()`] with the `cutoff` argument instead.
 #' @inheritParams closeness
 #' @keywords internal
 #' @export
@@ -338,11 +483,13 @@ closeness.estimate <- estimate_closeness
 #' @rdname arpack
 #' @family arpack
 #' @export
-arpack_defaults <- list(
-  bmat = "I", n = 0, which = "XX", nev = 1, tol = 0.0,
-  ncv = 3, ldv = 0, ishift = 1, maxiter = 3000, nb = 1,
-  mode = 1, start = 0, sigma = 0.0, sigmai = 0.0
-)
+arpack_defaults <- function() {
+  list(
+    bmat = "I", n = 0, which = "XX", nev = 1, tol = 0.0,
+    ncv = 3, ldv = 0, ishift = 1, maxiter = 3000, nb = 1,
+    mode = 1, start = 0, sigma = 0.0, sigmai = 0.0
+  )
+}
 
 #' ARPACK eigenvector calculation
 #'
@@ -451,8 +598,8 @@ arpack_defaults <- list(
 #' re-orthogonalization.} } } Please see the ARPACK documentation for
 #' additional details.
 #'
-#' @aliases arpack arpack-options igraph.arpack.default arpack.unpack.complex
-#' arpack_defaults
+#' @aliases arpack arpack-options arpack.unpack.complex
+#' @aliases arpack_defaults
 #' @param func The function to perform the matrix-vector multiplication. ARPACK
 #'   requires to perform these by the user. The function gets the vector \eqn{x}
 #'   as the first argument, and it should return \eqn{Ax}, where \eqn{A} is the
@@ -532,8 +679,18 @@ arpack_defaults <- list(
 #' }
 #' @family arpack
 #' @export
-arpack <- function(func, extra = NULL, sym = FALSE, options = arpack_defaults,
+arpack <- function(func, extra = NULL, sym = FALSE, options = arpack_defaults(),
                    env = parent.frame(), complex = !sym) {
+
+  if (is.function(options)) {
+    lifecycle::deprecate_soft(
+      "1.6.0",
+      "arpack(options = 'must be a list')",
+      details = c("`arpack_defaults()` is now a function, use `options = arpack_defaults()` instead of `options = arpack_defaults`.")
+    )
+    options <- options()
+  }
+
   if (!is.list(options) ||
     (is.null(names(options)) && length(options) != 0)) {
     stop("options must be a named list")
@@ -541,18 +698,18 @@ arpack <- function(func, extra = NULL, sym = FALSE, options = arpack_defaults,
   if (any(names(options) == "")) {
     stop("all options must be named")
   }
-  if (any(!names(options) %in% names(arpack_defaults))) {
+
+  defaults <- arpack_defaults()
+  if (any(!names(options) %in% names(defaults))) {
     stop(
       "unkown ARPACK option(s): ",
-      paste(setdiff(names(options), names(arpack_defaults)),
+      paste(setdiff(names(options), names(defaults)),
         collapse = ", "
       )
     )
   }
 
-  options.tmp <- arpack_defaults
-  options.tmp[names(options)] <- options
-  options <- options.tmp
+  options <- modify_list(defaults, options)
 
   if (sym && complex) {
     complex <- FALSE
@@ -591,9 +748,9 @@ arpack <- function(func, extra = NULL, sym = FALSE, options = arpack_defaults,
 
 arpack.unpack.complex <- function(vectors, values, nev) {
   # Argument checks
-  vectors <- as.matrix(structure(as.double(vectors), dim = dim(vectors)))
-  values <- as.matrix(structure(as.double(values), dim = dim(values)))
-  nev <- as.integer(nev)
+  vectors[] <- as.numeric(vectors)
+  values[] <- as.numeric(values)
+  nev <- as.numeric(nev)
 
   on.exit(.Call(R_igraph_finalizer))
   # Function call
@@ -617,7 +774,6 @@ arpack.unpack.complex <- function(vectors, values, nev) {
 #' eigenvalues and eigenvectors of the adjacency matrix of the graph. This
 #' effectively means that the measure can only be calculated for small graphs.
 #'
-#' @aliases subgraph.centrality
 #' @param graph The input graph, it should be undirected, but the
 #'   implementation does not check this currently.
 #' @param diag Boolean scalar, whether to include the diagonal of the adjacency
@@ -677,7 +833,7 @@ subgraph_centrality <- function(graph, diag = FALSE) {
 #' Note that ARPACK might be unstable for graphs with multiple components, e.g.
 #' graphs with isolate vertices.
 #'
-#' @aliases graph.eigen spectrum igraph.eigen.default
+#' @aliases spectrum igraph.eigen.default
 #' @param graph The input graph, can be directed or undirected.
 #' @param algorithm The algorithm to use. Currently only `arpack` is
 #'   implemented, which uses the ARPACK solver. See also [arpack()].
@@ -712,7 +868,21 @@ subgraph_centrality <- function(graph, diag = FALSE) {
 #'
 #' @family centrality
 #' @export
-spectrum <- eigen_adjacency_impl
+spectrum <- function(graph, algorithm=c("arpack", "auto", "lapack", "comp_auto", "comp_lapack", "comp_arpack"), which=list(), options=arpack_defaults()) {
+  if (is.function(options)) {
+    lifecycle::deprecate_soft(
+      "1.6.0",
+      "spectrum(options = 'must be a list')",
+      details = c("`arpack_defaults()` is now a function, use `options = arpack_defaults()` instead of `options = arpack_defaults`.")
+    )
+    options <- options()
+  }
+
+  eigen_adjacency_impl(graph,
+                       algorithm = algorithm,
+                       which = which,
+                       options = options)
+}
 
 eigen_defaults <- function() {
   list(
@@ -768,7 +938,6 @@ eigen_defaults <- function() {
 #' From igraph version 0.5 this function uses ARPACK for the underlying
 #' computation, see [arpack()] for more about ARPACK in igraph.
 #'
-#' @aliases evcent eigen_centrality
 #' @param graph Graph to be analyzed.
 #' @param directed Logical scalar, whether to consider direction of the edges
 #'   in directed graphs. It is ignored for undirected graphs.
@@ -807,15 +976,33 @@ eigen_defaults <- function() {
 #' eigen_centrality(g)
 #' @family centrality
 #' @export
-eigen_centrality <- eigenvector_centrality_impl
+eigen_centrality <- function(graph,
+                             directed = FALSE,
+                             scale = TRUE,
+                             weights = NULL,
+                             options = arpack_defaults()) {
 
+  if (is.function(options)) {
+    lifecycle::deprecate_soft(
+      "1.6.0",
+      "eigen_centrality(options = 'must be a list')",
+      details = c("`arpack_defaults()` is now a function, use `options = arpack_defaults()` instead of `options = arpack_defaults`.")
+    )
+    options <- options()
+  }
+
+  eigenvector_centrality_impl(graph = graph,
+                              directed = directed,
+                              scale = scale,
+                              weights = weights,
+                              options = options)
+}
 
 #' Strength or weighted vertex degree
 #'
 #' Summing up the edge weights of the adjacent edges for each vertex.
 #'
 #'
-#' @aliases graph.strength strength
 #' @param graph The input graph.
 #' @param vids The vertices for which the strength will be calculated.
 #' @param mode Character string, \dQuote{out} for out-degree, \dQuote{in} for
@@ -825,7 +1012,8 @@ eigen_centrality <- eigenvector_centrality_impl
 #' @param weights Weight vector. If the graph has a `weight` edge
 #'   attribute, then this is used by default. If the graph does not have a
 #'   `weight` edge attribute and this argument is `NULL`, then a
-#'   warning is given and [degree()] is called.
+#'   [degree()] is called. If this is `NA`, then no edge weights are used
+#'   (even if the graph has a `weight` edge attribute).
 #' @return A numeric vector giving the strength of the vertices.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso [degree()] for the unweighted version.
@@ -866,7 +1054,6 @@ strength <- strength_impl
 #'
 #' For vertices with degree less than two the function returns `NaN`.
 #'
-#' @aliases graph.diversity diversity
 #' @param graph The input graph. Edge directions are ignored.
 #' @param weights `NULL`, or the vector of edge weights to use for the
 #'   computation. If `NULL`, then the \sQuote{weight} attibute is used. Note
@@ -906,7 +1093,6 @@ diversity <- diversity_impl
 #' For undirected matrices the adjacency matrix is symmetric and the hub
 #' scores are the same as authority scores.
 #'
-#' @aliases hub.score
 #' @param graph The input graph.
 #' @param scale Logical scalar, whether to scale the result to have a maximum
 #'   score of one. If no scaling is used then the result vector has unit length
@@ -946,16 +1132,43 @@ diversity <- diversity_impl
 #' hub_score(g2)$vector
 #' authority_score(g2)$vector
 #' @family centrality
-hub_score <- hub_score_impl
+hub_score <- function(graph, scale=TRUE, weights=NULL, options=arpack_defaults()) {
 
+  if (is.function(options)) {
+    lifecycle::deprecate_soft(
+      "1.6.0",
+      "hub_score(options = 'must be a list')",
+      details = c("`arpack_defaults()` is now a function, use `options = arpack_defaults()` instead of `options = arpack_defaults`.")
+    )
+    options <- options()
+  }
+
+  hub_score_impl(graph = graph,
+                 scale = scale,
+                 weights = weights,
+                 options = options)
+}
 
 #' @rdname hub_score
-#' @aliases authority.score
 #' @param options A named list, to override some ARPACK options. See
 #'   [arpack()] for details.
 #' @export
-authority_score <- authority_score_impl
+authority_score <- function(graph, scale=TRUE, weights=NULL, options=arpack_defaults()) {
+  if (is.function(options)) {
+    lifecycle::deprecate_soft(
+      "1.6.0",
+      I("arpack_defaults"),
+      "arpack_defaults()",
+      details = c("So the function arpack_defaults(), not an object called arpack_defaults.")
+    )
+    options <- arpack_defaults()
+  }
 
+  authority_score_impl(graph = graph,
+                       scale = scale,
+                       weights = weights,
+                       options = options)
+}
 
 #' The Page Rank algorithm
 #'
@@ -978,7 +1191,6 @@ authority_score <- authority_score_impl
 #' PageRank for only some of the vertices does not result in any performance
 #' increase at all.
 #'
-#' @aliases page.rank page_rank
 #' @param graph The graph object.
 #' @param algo Character scalar, which implementation to use to carry out the
 #'   calculation. The default is `"prpack"`, which uses the PRPACK library
@@ -1188,7 +1400,6 @@ bonpow.sparse <- function(graph, nodes = V(graph), loops = FALSE,
 #' theory motivates use of this measure, you should be very careful to choose a
 #' decay parameter on a non-ad hoc basis.
 #'
-#' @aliases bonpow
 #' @param graph the input graph.
 #' @param nodes vertex sequence indicating which vertices are to be included in
 #'   the calculation.  By default, all vertices are included.
@@ -1368,7 +1579,6 @@ alpha.centrality.sparse <- function(graph, nodes = V(graph), alpha = 1,
 #' vertices and \eqn{\alpha}{alpha} is the relative importance of the
 #' endogenous versus exogenous factors.
 #'
-#' @aliases alpha.centrality
 #' @param graph The input graph, can be directed or undirected. In undirected
 #'   graphs, edges are treated as if they were reciprocal directed ones.
 #' @param nodes Vertex sequence, the vertices for which the alpha centrality
