@@ -1,4 +1,64 @@
 
+#' Various vertex shapes when plotting igraph graphs
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `igraph.shape.noplot()` was renamed to `shape_noplot()` to create a more
+#' consistent API.
+#' @inheritParams shape_noplot
+#' @keywords internal
+#' @export
+igraph.shape.noplot <- function(coords, v = NULL, params) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "igraph.shape.noplot()", "shape_noplot()")
+  shape_noplot(coords = coords, v = v, params = params)
+} # nocov end
+
+#' Various vertex shapes when plotting igraph graphs
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `igraph.shape.noclip()` was renamed to `shape_noclip()` to create a more
+#' consistent API.
+#' @inheritParams shape_noclip
+#' @keywords internal
+#' @export
+igraph.shape.noclip <- function(coords, el, params, end = c("both", "from", "to")) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "igraph.shape.noclip()", "shape_noclip()")
+  shape_noclip(coords = coords, el = el, params = params, end = end)
+} # nocov end
+
+#' Various vertex shapes when plotting igraph graphs
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `vertex.shapes()` was renamed to `shapes()` to create a more
+#' consistent API.
+#' @inheritParams shapes
+#' @keywords internal
+#' @export
+vertex.shapes <- function(shape = NULL) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "vertex.shapes()", "shapes()")
+  shapes(shape = shape)
+} # nocov end
+
+#' Various vertex shapes when plotting igraph graphs
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `add.vertex.shape()` was renamed to `add_shape()` to create a more
+#' consistent API.
+#' @inheritParams add_shape
+#' @keywords internal
+#' @export
+add.vertex.shape <- function(shape, clip = shape_noclip, plot = shape_noplot, parameters = list()) { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "add.vertex.shape()", "add_shape()")
+  add_shape(shape = shape, clip = clip, plot = plot, parameters = parameters)
+} # nocov end
+
 #   IGraph R package
 #   Copyright (C) 2003-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -151,8 +211,7 @@
 #' `shape_noplot()` is a very simple (and probably not very
 #' useful) plotting function, that does not plot anything.
 #'
-#' @aliases add.vertex.shape igraph.shape.noclip igraph.shape.noplot
-#'   vertex.shapes igraph.vertex.shapes
+#' @aliases   igraph.vertex.shapes
 #'
 #' @param shape Character scalar, name of a vertex shape. If it is
 #'    `NULL` for `shapes()`, then the names of all defined
@@ -274,7 +333,6 @@ shapes <- function(shape = NULL) {
 }
 
 #' @rdname shapes
-#' @family plot.shapes
 #' @export
 shape_noclip <- function(coords, el, params,
                          end = c("both", "from", "to")) {
@@ -290,14 +348,12 @@ shape_noclip <- function(coords, el, params,
 }
 
 #' @rdname shapes
-#' @family plot.shapes
 #' @export
 shape_noplot <- function(coords, v = NULL, params) {
   invisible(NULL)
 }
 
 #' @rdname shapes
-#' @family plot.shapes
 #' @export
 add_shape <- function(shape, clip = shape_noclip,
                       plot = shape_noplot,
@@ -604,7 +660,7 @@ add_shape <- function(shape, clip = shape_noclip,
   rec.shift <- function(x0, y0, x1, y1, vsize, vsize2) {
     m <- (y0 - y1) / (x0 - x1)
     l <- cbind(
-      x1 - vsize / m, y1 - vsize2,
+      x1 - vsize2 / m, y1 - vsize2,
       x1 - vsize, y1 - vsize * m,
       x1 + vsize2 / m, y1 + vsize2,
       x1 + vsize, y1 + vsize * m
@@ -1018,11 +1074,14 @@ mypie <- function(x, y, values, radius, edges = 200, col = NULL, angle = 45,
   ## Need to create a separate image for every different vertex color
   allcols <- unique(vertex.color)
   images <- lapply(allcols, function(col) {
-    img <- .Call(C_R_igraph_getsphere,
-      pos = c(0.0, 0.0, 10.0), radius = 7.0,
-      color = col2rgb(col) / 255, bgcolor = c(0, 0, 0),
-      lightpos = list(c(-2, 2, 2)), lightcolor = list(c(1, 1, 1)),
-      width = 100L, height = 100L
+    img <- getsphere(
+      spos = c(0.0, 0.0, 10.0),
+      sradius = 7.0,
+      scolor = col2rgb(col) / 255,
+      lightpos = list(c(-2, 2, 2)),
+      lightcolor = list(c(1, 1, 1)),
+      swidth = 100L,
+      sheight = 100L
     )
     as.raster(img)
   })
